@@ -1,5 +1,5 @@
 package HTML::ParseBrowser;
-$HTML::ParseBrowser::VERSION = '1.11';
+$HTML::ParseBrowser::VERSION = '1.12';
 use 5.006;
 use strict;
 use warnings;
@@ -138,7 +138,6 @@ sub Parse {
         }
 
         m!^Edge/(([0-9]+)\.([0-9]+))! and do {
-print STDERR "** EDGE **\n";
             $browser->{name} = 'Edge';
             $browser->{version}->{v} = $1;
             $browser->{version}->{major} = $2;
@@ -171,7 +170,7 @@ print STDERR "** EDGE **\n";
 
         if (/^Win/) {
             $browser->{os} = $_;
-            $browser->{ostype} = 'Windows';
+            $browser->{ostype} = 'Windows' . (/phone/i ? ' Phone' : '');
             if (/Windows NT\s*((\d+)(\.\d+)?)/ || /^WinNT((\d+)(\.\d+)?)/) {
                 $browser->{ostype} = 'Windows NT';
                 $version = $1;
@@ -196,7 +195,7 @@ print STDERR "** EDGE **\n";
                     $browser->{osvers} = $version;
                 }
             }
-            elsif (/Windows (\d+(\.\d+)?)/) {
+            elsif (/Windows (?:Phone )?(\d+(\.\d+)?)/) {
                 $browser->{osvers} = $1;
             } elsif (/Win(\w\w)/i) {
                 $browser->{osvers} = $1;
@@ -214,7 +213,7 @@ print STDERR "** EDGE **\n";
         }
 
         # TODO: parsing of version and osarc doesn't always get it right. See Danish Opera test
-        if (/Android\s([\.0-9]+)/) {
+        if (/Android\s([\.0-9]+)/ && lc($browser->{name}) ne 'edge') {
             $browser->{os}     = 'Android';
             $browser->{ostype} = 'Linux';
             $browser->{osvers} = $1;
@@ -298,10 +297,10 @@ HTML::ParseBrowser - Simple interface for User-Agent string parsing
 =head1 SYNOPSIS
 
   use HTML::ParseBrowser;
-  
+
   # Opera 6 on Windows 98, French
   my $uastring = 'Mozilla/4.0 (compatible; MSIE 5.0; Windows 98) Opera 6.0  [fr]';
-  
+
   my $ua = HTML::ParseBrowser->new($uastring);
   print "Browser  : ", $ua->name, "\n";
   print "Version  : ", $ua->v, "\n";
@@ -479,7 +478,7 @@ a given agent is a robot/crawler though.
 =head1 REPOSITORY
 
 L<https://github.com/neilbowers/HTML-ParseBrowser>
- 
+
 =head1 AUTHOR
 
 Dodger (aka Sean Cannon)
